@@ -1,3 +1,4 @@
+use crate::config::Keys;
 use crate::ui::components::StyleColorSymbol;
 use crate::ui::model::MAX_DEPTH;
 use crate::ui::{Id, LIMsg, Model, Msg, TEMsg, YSMsg};
@@ -7,17 +8,15 @@ use std::fs::{remove_dir_all, remove_file, rename};
 use std::path::{Path, PathBuf};
 use tui_realm_treeview::{Node, Tree, TreeView, TREE_CMD_CLOSE, TREE_CMD_OPEN, TREE_INITIAL_NODE};
 use tuirealm::command::{Cmd, CmdResult, Direction, Position};
-use tuirealm::event::{Key, KeyEvent, KeyModifiers};
+use tuirealm::event::{Key, KeyEvent, KeyModifiers, NoUserEvent};
 use tuirealm::props::{Alignment, BorderType, Borders, TableBuilder, TextSpan};
-// use tuirealm::tui::style::{Color, Style};
 use tuirealm::tui::style::Color;
-use tuirealm::{
-    AttrValue, Attribute, Component, Event, MockComponent, NoUserEvent, State, StateValue,
-};
+use tuirealm::{AttrValue, Attribute, Component, Event, MockComponent, State, StateValue};
 
 #[derive(MockComponent)]
 pub struct MusicLibrary {
     component: TreeView,
+    keys: Keys,
 }
 
 impl MusicLibrary {
@@ -25,6 +24,7 @@ impl MusicLibrary {
         tree: &Tree,
         initial_node: Option<String>,
         color_mapping: &StyleColorSymbol,
+        keys: &Keys,
     ) -> Self {
         // Preserve initial node if exists
         let initial_node = match initial_node {
@@ -50,6 +50,7 @@ impl MusicLibrary {
                 // .highlight_symbol("🦄")
                 .with_tree(tree.clone())
                 .initial_node(initial_node),
+            keys: keys.clone(),
         }
     }
 }
@@ -58,14 +59,10 @@ impl Component<Msg, NoUserEvent> for MusicLibrary {
     #[allow(clippy::too_many_lines)]
     fn on(&mut self, ev: Event<NoUserEvent>) -> Option<Msg> {
         let result = match ev {
-            Event::Keyboard(KeyEvent {
-                code: Key::Left | Key::Char('h'),
-                modifiers: KeyModifiers::NONE,
-            }) => self.perform(Cmd::Custom(TREE_CMD_CLOSE)),
-            Event::Keyboard(KeyEvent {
-                code: Key::Right | Key::Char('l'),
-                modifiers: KeyModifiers::NONE,
-            }) => {
+            Event::Keyboard(key) if key == self.keys.vim_h => {
+                self.perform(Cmd::Custom(TREE_CMD_CLOSE))
+            }
+            Event::Keyboard(key) if key == self.keys.vim_l => {
                 let current_node = self.component.tree_state().selected().unwrap();
                 let p: &Path = Path::new(current_node);
                 if p.is_dir() {
@@ -76,6 +73,13 @@ impl Component<Msg, NoUserEvent> for MusicLibrary {
                     )));
                 }
             }
+            Event::Keyboard(key) if key == self.keys.vim_j => {
+                self.perform(Cmd::Move(Direction::Down))
+            }
+            Event::Keyboard(key) if key == self.keys.vim_k => {
+                self.perform(Cmd::Move(Direction::Up))
+            }
+
             Event::Keyboard(KeyEvent {
                 code: Key::Right | Key::Char('L'),
                 modifiers: KeyModifiers::SHIFT,
@@ -97,14 +101,6 @@ impl Component<Msg, NoUserEvent> for MusicLibrary {
                 code: Key::PageUp,
                 modifiers: KeyModifiers::NONE,
             }) => self.perform(Cmd::Scroll(Direction::Up)),
-            Event::Keyboard(KeyEvent {
-                code: Key::Down | Key::Char('j'),
-                modifiers: KeyModifiers::NONE,
-            }) => self.perform(Cmd::Move(Direction::Down)),
-            Event::Keyboard(KeyEvent {
-                code: Key::Up | Key::Char('k'),
-                modifiers: KeyModifiers::NONE,
-            }) => self.perform(Cmd::Move(Direction::Up)),
             Event::Keyboard(KeyEvent {
                 code: Key::Home | Key::Char('g'),
                 modifiers: KeyModifiers::NONE,
@@ -253,6 +249,7 @@ impl Model {
                     &self.tree.clone(),
                     current_node,
                     &self.config.style_color_symbol,
+                    &self.config.keys,
                 ),),
                 Vec::new()
             )
