@@ -7,8 +7,9 @@ use std::time::Duration;
 use tui_realm_stdlib::ProgressBar;
 // use tuirealm::command::CmdResult;
 use crate::ui::components::StyleColorSymbol;
+use tuirealm::event::NoUserEvent;
 use tuirealm::props::{Alignment, BorderType, Borders, Color, PropPayload, PropValue};
-use tuirealm::{AttrValue, Attribute, Component, Event, MockComponent, NoUserEvent};
+use tuirealm::{AttrValue, Attribute, Component, Event, MockComponent};
 
 #[derive(MockComponent)]
 pub struct Progress {
