@@ -46,8 +46,8 @@ use std::path::{Path, PathBuf};
 use std::sync::mpsc::{self, Receiver, Sender};
 use std::time::{Duration, Instant};
 use tui_realm_treeview::Tree;
+use tuirealm::event::NoUserEvent;
 use tuirealm::terminal::TerminalBridge;
-use tuirealm::NoUserEvent;
 use youtube_options::YoutubeOptions;
 
 pub const MAX_DEPTH: usize = 3;
@@ -118,7 +118,7 @@ impl Model {
         let viuer_supported = (viuer::KittySupport::Local == viuer::get_kitty_support())
             || viuer::is_iterm_supported();
         Self {
-            app: Self::init_app(&tree, &config.style_color_symbol),
+            app: Self::init_app(&tree, config),
             quit: false,
             redraw: true,
             last_redraw: Instant::now(),
