@@ -1,9 +1,4 @@
-use crate::{
-    song::Song,
-    ui::{Application, Id, IdColorEditor, IdTagEditor, Msg},
-    VERSION,
-};
-
+use crate::config::Termusic;
 use crate::ui::components::{
     draw_area_in, draw_area_top_right, CEHelpPopup, CELibraryBackground, CELibraryBorder,
     CELibraryForeground, CELibraryHighlight, CELibraryHighlightSymbol, CELibraryTitle,
@@ -12,28 +7,31 @@ use crate::ui::components::{
     CEPlaylistTitle, CEProgressBackground, CEProgressBorder, CEProgressForeground, CEProgressTitle,
     CERadioOk, DeleteConfirmInputPopup, DeleteConfirmRadioPopup, ErrorPopup, GSInputPopup,
     GSTablePopup, GlobalListener, HelpPopup, Label, Lyric, MessagePopup, MusicLibrary, Playlist,
-    Progress, QuitPopup, Source, StyleColorSymbol, TECounterDelete, TEHelpPopup, TEInputArtist,
-    TEInputTitle, TERadioTag, TESelectLyric, TETableLyricOptions, TETextareaLyric,
-    ThemeSelectTable, YSInputPopup, YSTablePopup,
+    Progress, QuitPopup, Source, TECounterDelete, TEHelpPopup, TEInputArtist, TEInputTitle,
+    TERadioTag, TESelectLyric, TETableLyricOptions, TETextareaLyric, ThemeSelectTable,
+    YSInputPopup, YSTablePopup,
 };
 use crate::ui::model::Model;
+use crate::{
+    song::Song,
+    ui::{Application, Id, IdColorEditor, IdTagEditor, Msg},
+    VERSION,
+};
 use std::convert::TryFrom;
 use std::path::Path;
 use std::str::FromStr;
 use std::time::{Duration, Instant};
 use tui_realm_treeview::Tree;
+use tuirealm::event::NoUserEvent;
 use tuirealm::props::{
     Alignment, AttrValue, Attribute, Color, PropPayload, PropValue, TextModifiers, TextSpan,
 };
 use tuirealm::tui::layout::{Constraint, Direction, Layout};
 use tuirealm::tui::widgets::Clear;
-use tuirealm::{EventListenerCfg, NoUserEvent};
+use tuirealm::EventListenerCfg;
 
 impl Model {
-    pub fn init_app(
-        tree: &Tree,
-        color_mapping: &StyleColorSymbol,
-    ) -> Application<Id, Msg, NoUserEvent> {
+    pub fn init_app(tree: &Tree, config: &Termusic) -> Application<Id, Msg, NoUserEvent> {
         // Setup application
         // NOTE: NoUserEvent is a shorthand to tell tui-realm we're not going to use any custom user event
         // NOTE: the event listener is configured to use the default crossterm input listener and to raise a Tick event each second
@@ -48,18 +46,35 @@ impl Model {
         assert!(app
             .mount(
                 Id::Library,
-                Box::new(MusicLibrary::new(tree, None, color_mapping)),
+                Box::new(MusicLibrary::new(
+                    tree,
+                    None,
+                    &config.style_color_symbol,
+                    &config.keys
+                )),
                 vec![]
             )
             .is_ok());
         assert!(app
-            .mount(Id::Playlist, Box::new(Playlist::new(color_mapping)), vec![])
+            .mount(
+                Id::Playlist,
+                Box::new(Playlist::new(&config.style_color_symbol, &config.keys)),
+                vec![]
+            )
             .is_ok());
         assert!(app
-            .mount(Id::Progress, Box::new(Progress::new(color_mapping)), vec![])
+            .mount(
+                Id::Progress,
+                Box::new(Progress::new(&config.style_color_symbol)),
+                vec![]
+            )
             .is_ok());
         assert!(app
-            .mount(Id::Lyric, Box::new(Lyric::new(color_mapping)), vec![])
+            .mount(
+                Id::Lyric,
+                Box::new(Lyric::new(&config.style_color_symbol)),
+                vec![]
+            )
             .is_ok());
         assert!(app
             .mount(
@@ -79,8 +94,8 @@ impl Model {
         assert!(app
             .mount(
                 Id::GlobalListener,
-                Box::new(GlobalListener::default()),
-                Self::subscribe(),
+                Box::new(GlobalListener::new(config)),
+                Self::subscribe(config),
             )
             .is_ok());
         // Active library
@@ -201,11 +216,7 @@ impl Model {
         // pub fn mount_error_popup(&mut self, err: impl ToString) {
         assert!(self
             .app
-            .remount(
-                Id::ErrorPopup,
-                Box::new(ErrorPopup::new(err.to_string())),
-                vec![]
-            )
+            .remount(Id::ErrorPopup, Box::new(ErrorPopup::new(err)), vec![])
             .is_ok());
         assert!(self.app.active(&Id::ErrorPopup).is_ok());
         // self.app.lock_subs();
@@ -357,9 +368,6 @@ impl Model {
             return;
         }
 
-        if let Err(e) = self.clear_photo() {
-            self.mount_error_popup(format!("clear photo error: {}", e).as_str());
-        }
         let p = p.to_string_lossy();
         match Song::from_str(&p) {
             Ok(s) => {
@@ -369,7 +377,7 @@ impl Model {
                         Id::TagEditor(IdTagEditor::TELabelHint),
                         Box::new(
                             Label::default()
-                                .text("Press <ENTER> to search:".to_string())
+                                .text("Press <ENTER> to search:")
                                 .alignment(Alignment::Left)
                                 .background(Color::Reset)
                                 .foreground(Color::Magenta)
@@ -445,6 +453,9 @@ impl Model {
                 self.mount_error_popup(format!("song load error: {}", e).as_ref());
             }
         };
+        if let Err(e) = self.update_photo() {
+            self.mount_error_popup(format!("clear photo error: {}", e).as_str());
+        }
     }
     pub fn umount_tageditor(&mut self) {
         self.app
@@ -1001,10 +1012,6 @@ impl Model {
 
     #[allow(clippy::too_many_lines, clippy::cognitive_complexity)]
     pub fn mount_color_editor(&mut self) {
-        if let Err(e) = self.clear_photo() {
-            self.mount_error_popup(format!("clear photo error: {}", e).as_str());
-        }
-
         let style_color_symbol = self.ce_style_color_symbol.clone();
         assert!(self
             .app
@@ -1012,7 +1019,7 @@ impl Model {
                 Id::ColorEditor(IdColorEditor::LabelHint),
                 Box::new(
                     Label::default()
-                        .text("  Color Editor. You can select theme to change the general style, or you can change specific color.".to_string())
+                        .text("  Color Editor. You can select theme to change the general style, or you can change specific color.")
                         .alignment(Alignment::Left)
                         .background(Color::Reset)
                         .foreground(Color::Magenta)
@@ -1211,6 +1218,9 @@ impl Model {
             .is_ok());
         self.theme_select_sync();
         self.app.lock_subs();
+        if let Err(e) = self.update_photo() {
+            self.mount_error_popup(format!("clear photo error: {}", e).as_str());
+        }
     }
 
     pub fn umount_color_editor(&mut self) {
